@@ -17,15 +17,23 @@
 #' library(mlr3)
 #' lung = mlr3misc::load_dataset("lung", package = "survival")
 #' lung$status = (lung$status == 2L)
-#' b = as_data_backend(lung)
 #' task = TaskSurv$new("lung",
-#'   backend = b, time = "time",
+#'   backend = lung, time = "time",
 #'   event = "status")
 #'
+#' # meta data
 #' task$target_names
 #' task$feature_names
 #' task$formula()
+#'
+#' # survival data
 #' task$truth()
+#' task$times()
+#' task$status()
+#' task$unique_times()
+#' task$unique_event_times()
+#' task$risk_set(time = 700)
+#'
 TaskSurv = R6::R6Class("TaskSurv",
   inherit = TaskSupervised,
   public = list(
@@ -48,32 +56,33 @@ TaskSurv = R6::R6Class("TaskSurv",
     #'
     #' @param type (`character(1)`)\cr
     #' Name of the column giving the type of censoring. Default is 'right' censoring.
-    initialize = function(id, backend, time, event, time2,
-      type = c("right", "left", "counting", "interval", "interval2", "mstate")) {
+    initialize = function(id, backend, time = "time", event = "event", time2,
+      type = c("right", "left", "counting", "interval", "mstate")) {
+
       type = match.arg(type)
 
+      backend = as_data_backend(backend)
+
+      c_ev = backend$.__enclos_env__$private$.data[, event, with=FALSE][[1]]
+      if (type == "mstate") {
+        assert_factor(c_ev)
+      } else if (type == "interval") {
+        assert_integerish(c_ev, lower = 0, upper = 3)
+      } else if (!is.logical(c_ev)) {
+        assert_integerish(c_ev, lower = 0, upper = 2)
+      }
+
+      private$.censtype = type
+
       if (type %in% c("right", "left", "mstate")) {
         super$initialize(
           id = id, task_type = "surv", backend = backend,
           target = c(time, event))
-      } else if (type %in% "interval2") {
-        super$initialize(
-          id = id, task_type = "surv", backend = backend,
-          target = c(time, time2))
       } else {
         super$initialize(
           id = id, task_type = "surv", backend = backend,
           target = c(time, time2, event))
       }
-
-      if (type %nin% "interval2") {
-        event = self$data(cols = event)[[1L]]
-        if (!is.logical(event)) {
-          assert_integerish(event, lower = 0, upper = 3)
-        }
-      }
-
-      private$.censtype = type
     },
 
     #' @description
@@ -85,9 +94,7 @@ TaskSurv = R6::R6Class("TaskSurv",
       tn = self$target_names
       d = self$data(rows, cols = self$target_names)
       args = list(time = d[[tn[1L]]], type = self$censtype)
-      if (self$censtype %in% "interval2") {
-        args$time2 = d[[tn[2L]]]
-      } else if (length(tn) == 2) {
+      if (length(tn) == 2) {
         args$event = as.integer(d[[tn[2L]]])
       } else {
         args$event = as.integer(d[[tn[3L]]])
@@ -111,21 +118,75 @@ TaskSurv = R6::R6Class("TaskSurv",
     formula = function(rhs = NULL) {
       # formula appends the rhs argument to Surv(time, event)~
       tn = self$target_names
-      if (self$censtype %in% "interval2") {
-        lhs = sprintf("Surv(time = %s, time2 = %s, type = 'interval2')", tn[1L], tn[2L])
-      } else if (length(tn) == 2) {
+      if (length(tn) == 2) {
         lhs = sprintf("Surv(%s, %s, type = '%s')", tn[1L], tn[2L], self$censtype)
       } else {
         lhs = sprintf("Surv(%s, %s, %s, type = '%s')", tn[1L], tn[2L], tn[3L], self$censtype)
       }
       formulate(lhs, rhs %??% ".", env = getNamespace("survival"))
+    },
+
+    #' @description
+    #' Returns the (unsorted) outcome times.
+    #' @return `numeric()`
+    times = function(rows = NULL) {
+      truth = self$truth(rows)
+      if (self$censtype %in% c("interval", "counting")) {
+        return(truth[, 1:2])
+      } else {
+        return(truth[, 1])
+      }
+    },
+
+    #' @description
+    #' Returns the event indicator (aka censoring/survival indicator).
+    #' If `censtype` is `"right"` or `"left"` then `1` is event and `0` is censored.
+    #' If `censtype` is `"mstate"` then `0` is censored and all other values are different events.
+    #' If `censtype` is `"interval"` then `0` is right-censored, `1` is event, `2` is left-censored,
+    #' `3` is interval-censored.
+    #' See [survival::Surv].
+    #' @return `integer()`
+    status = function(rows = NULL) {
+      truth = self$truth(rows)
+      if (self$censtype %in% c("interval", "counting")) {
+        status = truth[, 3L]
+      } else {
+        status = truth[, 2L]
+      }
+
+      as.integer(status)
+    },
+
+    #' @description
+    #' Returns the sorted unique outcome times.
+    #' @return `numeric()`
+    unique_times = function(rows = NULL) {
+      sort(unique(self$times(rows)))
+    },
+
+    #' @description
+    #' Returns the sorted unique event (or failure) outcome times.
+    #' @return `numeric()`
+    unique_event_times = function(rows = NULL) {
+      sort(unique(self$times(rows)[self$status(rows) != 0]))
+    },
+
+    #' @description
+    #' Returns the `row_ids` of the observations 'at risk' (not dead or censored) at `time`.
+    #' @param time (`numeric(1)`) \cr Time to return risk set for, if `NULL` returns all `row_ids`.
+    #' @return `integer()`
+    risk_set = function(time = NULL) {
+      if (is.null(time)) {
+        self$row_ids
+      } else {
+        self$row_ids[self$times() >= time]
+      }
     }
   ),
 
   active = list(
     #' @field censtype `character(1)`\cr
-    #' Returns the type of censoring, one of "right", "left", "counting", "interval", "interval2"
-    #' or "mstate".
+    #' Returns the type of censoring, one of "right", "left", "counting", "interval", or "mstate".
     censtype = function() {
       return(private$.censtype)
     }
