@@ -1,15 +1,15 @@
 generate_tasks.LearnerDens = function(learner, N = 30L, ...) { # nolint
-  task = TaskDens$new("proto", rnorm(N))
+  task = mlr3proba::TaskDens$new("proto", rnorm(N))
 
   tasks = list()
-  tasks$feat_single_integer = TaskDens$new("feat_single_integer",
+  tasks$feat_single_integer = mlr3proba::TaskDens$new("feat_single_integer",
                                            data.frame(integer = rbinom(N, 10, 0.5)))
-  tasks$feat_single_numeric = TaskDens$new("feat_single_numeric", data.frame(numeric = rnorm(N)))
-  tasks$weights = TaskDens$new("feat_single_numeric", data.frame(x = rnorm(N), weights = runif(N)))
+  tasks$feat_single_numeric = mlr3proba::TaskDens$new("feat_single_numeric", data.frame(numeric = rnorm(N)))
+  tasks$weights = mlr3proba::TaskDens$new("feat_single_numeric", data.frame(x = rnorm(N), weights = runif(N)))
 
   # generate sanity task
   data = with_seed(100, rnorm(1000, 10, 1))
-  tasks$sanity = TaskDens$new("sanity", data)
+  tasks$sanity = mlr3proba::TaskDens$new("sanity", data)
   tasks$sanity_reordered = tasks$sanity$clone(deep = TRUE)
 
   tasks
@@ -29,16 +29,21 @@ generate_tasks.LearnerSurv = function(learner, N = 20L, ...) { # nolint
   obs_time = ifelse(real_time <= cens_time, real_time, cens_time)
 
   data = cbind(data.table::data.table(time = obs_time, event = status), generate_data(learner, N))
-  task = TaskSurv$new("proto", mlr3::as_data_backend(data), time = "time", event = "event")
+  task = mlr3proba::TaskSurv$new("proto", mlr3::as_data_backend(data), time = "time", event = "event")
   tasks = generate_generic_tasks(learner, task)
 
   # generate sanity task
+  if (N %% 2 == 1) N = N + 1
   data = with_seed(100, {
-    data = data.table::data.table(time = obs_time, event = status, x1 = real_time + rnorm(N, sd = 2),
-      unimportant = runif(N, 0, 20))
-  })
-  tasks$sanity = TaskSurv$new("sanity", mlr3::as_data_backend(data), time = "time", event = "event")
+    data.table::data.table(
+    x = c(rep(0, N/2), rep(1, N/2)),
+    unimportant = runif(N),
+    time = c(rep(10, N/2), rep(100, N/2)),
+    event = rbinom(N, 1, 0.9)
+  )})
+  tasks$sanity = mlr3proba::TaskSurv$new("sanity", mlr3::as_data_backend(data), time = "time", event = "event")
   tasks$sanity_reordered = tasks$sanity$clone(deep = TRUE)
+  tasks$sanity_reordered$id = "sanity_reordered"
 
   tasks
 }
@@ -46,26 +51,26 @@ registerS3method("generate_tasks", "LearnerSurv", generate_tasks.LearnerSurv)
 
 sanity_check.PredictionSurv = function(prediction, ...) { # nolint
   # sanity check discrimination
-  x = prediction$score() >= 0.5
+  x = prediction$score() >= 0.6
 
   if ("lp" %in% prediction$predict_types) {
     # crank should equal lp if available
     x = x & all(all.equal(as.numeric(prediction$lp),
                           as.numeric(prediction$crank)) == TRUE)
-  }
-
-  if ("distr" %in% prediction$predict_types) {
-    # crank should have opposite rank to mean distr if available
-    mean = suppressMessages(as.numeric(-prediction$distr$mean(cubature = TRUE)))
+  } else if ("response" %in% prediction$predict_types) {
+    # otherwise crank should equal -response if available
+    x = x & all(all.equal(-as.numeric(prediction$response),
+                          as.numeric(prediction$crank)) == TRUE)
+  } else if ("distr" %in% prediction$predict_types) {
+    # try faster method first
+    mean = suppressMessages(as.numeric(prediction$distr$mean(cubature = FALSE)))
+    if (any(is.nan(mean))) {
+      mean = suppressMessages(as.numeric(prediction$distr$mean(cubature = TRUE)))
+    }
     if(!any(is.nan(mean))) {
-      x = x & all(all.equal(rank(mean), rank(as.numeric(prediction$crank))) == TRUE)
+      # otherwise crank should equal -distr$mean if available
+      x = x & all(all.equal(-mean, as.numeric(prediction$crank)) == TRUE)
     }
-  }
-
-  if ("response" %in% prediction$predict_types) {
-    # crank should have opposite rank to pred time if available
-    x = x & all(all.equal(rank(as.numeric(-prediction$response)),
-                          rank(as.numeric(prediction$crank))) == TRUE)
   }
 
   x
